@@ -3,6 +3,7 @@
 # file, You can obtain one at https://mozilla.org/MPL/2.0/.
 from abc import ABC, abstractmethod
 from enum import Enum
+from pathlib import Path
 
 
 class EvaluatorResult(Enum):
@@ -20,8 +21,13 @@ class Evaluator(ABC):
     Base evaluator class
     """
 
+    @property
     @abstractmethod
-    def evaluate_testcase(self, build_path):
+    def target(self) -> str:
+        """The corresponding Fetcher target"""
+
+    @abstractmethod
+    def evaluate_testcase(self, build_path: Path) -> EvaluatorResult:
         """
         Method for evaluating testcase
 
