@@ -1,7 +1,10 @@
-import pytest
+from pathlib import Path
 
-from autobisect.evaluators import BrowserEvaluator
-from autobisect.evaluators import EvaluatorResult
+import pytest
+from grizzly.session import Session
+
+from autobisect.evaluators import BrowserEvaluator, EvaluatorResult
+from autobisect.evaluators.browser.browser import BrowserEvaluatorException
 
 
 def test_verify_build_status(mocker):
@@ -16,10 +19,10 @@ def test_verify_build_status(mocker):
             EvaluatorResult.BUILD_FAILED,
         ),
     )
-    browser = BrowserEvaluator("testcase.html")
-    assert browser.verify_build(None) is False
-    assert browser.verify_build(None) is True
-    assert browser.verify_build(None) is False
+    browser = BrowserEvaluator(Path("testcase.html"))
+    assert browser.verify_build(Path("firefox")) is False
+    assert browser.verify_build(Path("firefox")) is True
+    assert browser.verify_build(Path("firefox")) is False
 
 
 def test_evaluate_testcase_simple(mocker, tmp_path):
@@ -31,17 +34,17 @@ def test_evaluate_testcase_simple(mocker, tmp_path):
         autospec=True,
         return_value=EvaluatorResult.BUILD_PASSED,
     )
-    browser = BrowserEvaluator("testcase.html")
+    browser = BrowserEvaluator(Path("testcase.html"))
     (tmp_path / "firefox").touch()
-    assert browser.evaluate_testcase(str(tmp_path)) == EvaluatorResult.BUILD_PASSED
+    assert browser.evaluate_testcase(tmp_path) == EvaluatorResult.BUILD_PASSED
 
 
 def test_evaluate_testcase_non_existent_binary(tmp_path):
     """
     Test that BrowserEvaluator.evaluate_testcase fails when using a non-existent build path
     """
-    browser = BrowserEvaluator("testcase.html")
-    assert browser.evaluate_testcase(str(tmp_path)) == EvaluatorResult.BUILD_FAILED
+    browser = BrowserEvaluator(Path("testcase.html"))
+    assert browser.evaluate_testcase(tmp_path) == EvaluatorResult.BUILD_FAILED
 
 
 def test_launch_simple(mocker, tmp_path):
@@ -49,7 +52,8 @@ def test_launch_simple(mocker, tmp_path):
     Simple test of BrowserEvaluator.launch()
     """
     mocker.patch(
-        "grizzly.replay.ReplayManager.run", autospec=True, side_effect=(True, False)
+        "grizzly.replay.ReplayManager.main",
+        side_effect=(Session.EXIT_SUCCESS, Session.EXIT_FAILURE),
     )
 
     binary = tmp_path / "firefox"
@@ -58,21 +62,19 @@ def test_launch_simple(mocker, tmp_path):
     testcase.touch()
 
     browser = BrowserEvaluator(testcase)
-    assert browser.launch(binary, testcase, None, 1) == EvaluatorResult.BUILD_CRASHED
-    assert browser.launch(binary, testcase, None, 1) == EvaluatorResult.BUILD_PASSED
+    assert browser.launch(binary, testcase, 1) == EvaluatorResult.BUILD_CRASHED
+    assert browser.launch(binary, testcase, 1) == EvaluatorResult.BUILD_PASSED
 
 
-def test_launch_non_existent_binary(mocker, tmp_path):
+def test_launch_non_existent_binary(tmp_path):
     """
     Simple test of BrowserEvaluator.launch()
     """
-    mocker.patch("grizzly.replay.ReplayManager.run", side_effect=(True, False))
-
     binary = tmp_path / "firefox"
     testcase = tmp_path / "testcase.html"
     testcase.touch()
 
     browser = BrowserEvaluator(testcase)
 
-    with pytest.raises(AssertionError):
-        browser.launch(binary, testcase, None, 1)
+    with pytest.raises(BrowserEvaluatorException):
+        browser.launch(binary, testcase, 1)
